@@ -172,9 +172,9 @@ def rabbitmq(request):
     rabbit_conf = open(request.config.getvalue('rabbit_conf')).readlines()
     rabbit_conf = dict(line[:-1].split('=') for line in rabbit_conf)
 
-    tmpdir = path(mkdtemp('rabbitmq_fixture'))
-    rabbit_conf['RABBITMQ_LOG_BASE'] = str(tmpdir)[:64]
-    rabbit_conf['RABBITMQ_MNESIA_BASE'] = str(tmpdir)[:64]
+    tmpdir = path(mkdtemp(prefix='rabbitmq_fixture'))
+    rabbit_conf['RABBITMQ_LOG_BASE'] = str(tmpdir)
+    rabbit_conf['RABBITMQ_MNESIA_BASE'] = str(tmpdir)
 
     # setup environment variables
     for name, value in rabbit_conf.items():
@@ -191,23 +191,26 @@ def rabbitmq(request):
     )
     base_path = get_rabbit_path('RABBITMQ_MNESIA_BASE')
 
+    def wait():
+        pid_file = base_path / get_rabbit_env('RABBITMQ_NODENAME') + '.pid'
+        wait_cmd = config.rabbit.rabbit_ctl, '-q', 'wait', pid_file
+        subprocess.Popen(wait_cmd).communicate()
+
     def stop_and_reset():
         rabbit_executor.stop()
+        wait()
         base_path.rmtree()
+        tmpdir.exists() and tmpdir.rmtree()
     request.addfinalizer(stop_and_reset)
 
     rabbit_executor.start()
 
-    # wait
-    pid_file = base_path / get_rabbit_env('RABBITMQ_NODENAME') + '.pid'
-    wait_cmd = config.rabbit.rabbit_ctl, '-q', 'wait', pid_file
-    subprocess.Popen(wait_cmd).communicate()
-
     rabbit_params = pika.connection.ConnectionParameters(
         host=config.rabbit.host,
         port=config.rabbit.port,
         connection_attempts=3,
         retry_delay=2,
     )
+    wait()
     rabbit_connection = pika.BlockingConnection(rabbit_params)
     return rabbit_connection
